Module socialization.ccs.base_god_service
=========================================

Classes
-------

`BaseGodService()`
:   

    ### Ancestors (in MRO)

    * socialization.ccs.json_ws_active_service.JSONWebsocketActiveService

    ### Descendants

    * socialization.ccs.wrapped_god_service.WrappedGodService

    ### Methods

    `on_open(self, ws)`
    :